## 0.0.26

This new version includes updates to the dependency management of the project. The version of the project has been bumped up from 0.0.25 to 0.0.26.

### New Features

- No new features were added in this version.

### Updates

- The version of the project has been updated from 0.0.25 to 0.0.26 (894c25) (Eric Ma)
- The versions of the dependencies have been unpinned, allowing for the latest versions to be used (bc8d64) (Eric Ma)
- The 'langchain' dependency has been pinned to an exact version to ensure compatibility and stability (2b69d0) (Eric Ma)

### Bug Fixes

- No bug fixes were made in this version.

### Deprecations

- No deprecations were made in this version.
